dadi.Triallele API documentation
Description: Modeling triallelic data.

# Module `dadi.Triallele`

Modeling triallelic data.

Expand source code

    """
    Modeling triallelic data.
    """
    from . import numerics, integration, demographics, plotting, TriSpectrum_mod
    TriSpectrum = TriSpectrum_mod.TriSpectrum

## Sub-modules

`dadi.Triallele.TriSpectrum_mod`

  Contains triallelic Spectrum object

`dadi.Triallele.demographics`

  Equilibrium, two epoch, and three epoch (bottleneck) model with selection (sig1, sig2) on the two derived alleles

`dadi.Triallele.integration`

  Integration of phi for triallelic diffusion These methods include ones for the injection of density for new triallelic sites and integration forward …

`dadi.Triallele.numerics`
`dadi.Triallele.plotting`
`dadi.Triallele.transition1`
`dadi.Triallele.transition12`
`dadi.Triallele.transition1D`
`dadi.Triallele.transition2`